@@ -231,10 +231,10 @@ from typing import Any, Dict, Optional, Tuple, Union
 
 from ae.inspector import stack_vars                                                         # type: ignore
 from ae.i18n import default_language, get_f_string, translation                             # type: ignore
-from ae.gui_app import FLOW_KEY_SEP, module_globals, id_of_flow, MainAppBase                # type: ignore
+from ae.gui_app import FLOW_KEY_SEP, flow_action, id_of_flow, module_globals, MainAppBase   # type: ignore
 
 
-__version__ = '0.1.17'
+__version__ = '0.1.18'
 
 
 HELP_ID_PREFIX_FLOW = 'help_flow#'                                  #: message id prefix for flow change help texts
@@ -516,8 +516,9 @@ class HelpAppBase(MainAppBase, ABC):
             return False            # inactive help layout
 
         ret = self.help_display(help_id, help_vars, key_suffix='after' if changed else '', must_have=not changed)
-        if help_id == self.displayed_help_id and not changed:
-            ret = False             # allow to execute flow change of currently explained flow button
+        if not changed and (help_id == self.displayed_help_id or flow_action(nfi) == 'open'):
+            # allow to execute flow change of currently explained flow button or if open flow action with no help text
+            ret = False
         return ret
 
     @staticmethod
